    module VGATEST(
      input CLK, // 102,1Mhz for 1280x960 60Hz
      output VGA_HSYNC, VGA_VSYNC,
      output [7:0] VGA_R, VGA_G, VGA_B);
     
    localparam width   = 1280;
    localparam height  = 960;
    localparam x_front = 80;
    localparam x_sync  = 136;
    localparam x_back  = 216;
    localparam x_max   = x_sync + x_front + x_back + width;
    localparam y_front = 1;
    localparam y_sync  = 3;
    localparam y_back  = 30;
    localparam y_max   = y_sync + y_front + y_back + height;
     
    reg[11:0] x = 0, y = 0;
    reg[8:0] offset = 0;
    wire[7:0] color = (x < width) ? (x + offset[8:1]) ^ (y + offset[8:1]) : 0;
    assign VGA_HSYNC = (x >= width + x_front) && (x < x_max - x_back);
    assign VGA_VSYNC = (y >= height + y_front) && (y < y_max - y_back);
    assign VGA_R = color;
    assign VGA_G = 255 - color;
    assign VGA_B = color % 128;
     
    always @(posedge CLK)
    begin
      if (x == x_max - 1)
      begin
        x <= 0;
        if (y == y_max - 1)
        begin
          y <= 0;
          offset <= offset + 1;
        end else
          y <= y + 1;
      end else
        x <= x + 1;
    end
     
    endmodule 
